@@ -23,9 +23,17 @@ class ChDir(object):
         os.chdir(self.old_dir)
 
 
+def get_mac_dot_app_dir(dir_):
+    return os.path.dirname(os.path.dirname(os.path.dirname(dir_)))
+
+
 if FROZEN:  # pragma: no cover
     # we are running in a |PyInstaller| bundle
-    cwd = os.path.dirname(sys.argv[0])
+    app_cwd = os.path.dirname(sys.argv[0])
+    if app_cwd.endswith('MacOS') is True:
+        log.debug('Looks like we\'re dealing with a Mac Gui')
+        app_cwd = get_mac_dot_app_dir(app_cwd)
+
 else:
     # we are running in a normal Python environment
-    cwd = os.getcwd()
+    app_cwd = os.getcwd()
